import gi
import subprocess
gi.require_version('Gtk', '4.0')
gi.require_version('Adw', '1')
from gi.repository import Gtk, Adw, Gio, Gdk

class MyApp(Adw.Application):

    def __init__(self):
        super().__init__(application_id='com.example.MyApp',
                         flags=Gio.ApplicationFlags.FLAGS_NONE)
        self.connect('activate', self.on_activate)

    def on_activate(self, app):
        win = MyAppWindow(application=app)
        win.present()

class MyAppWindow(Adw.ApplicationWindow):

    def __init__(self, **kwargs):
        super().__init__(**kwargs)
        self.set_title("My GTK4 Application")
        self.set_default_size(800, 500)

        # Tworzenie kontenera głównego
        main_box = Gtk.Box(orientation=Gtk.Orientation.VERTICAL, spacing=6)
        self.set_content(main_box)

        # Tworzenie nagłówka
        header_bar = Adw.HeaderBar()
        header_bar.set_title_widget(Gtk.Label(label="MyApp"))

        # Dodanie nagłówka do głównego kontenera
        main_box.append(header_bar)

        # Tworzenie stylizacji CSS
        css_provider = Gtk.CssProvider()
        css_provider.load_from_data(b"""
            label.title {
                font-weight: bold;
                font-size: 20px;
            }
        """)

        # Dodanie stylizacji do kontekstu
        display = Gdk.Display.get_default()
        Gtk.StyleContext.add_provider_for_display(
            display,
            css_provider,
            Gtk.STYLE_PROVIDER_PRIORITY_APPLICATION
        )

        # Dodanie stylizowanej etykiety powitalnej
        title_label = Gtk.Label(label="Welcome in OpenMandriva GTK repository selector")
        title_label.get_style_context().add_class("title")
        title_label.set_margin_top(20)
        title_label.set_margin_bottom(10)
        title_label.set_halign(Gtk.Align.CENTER)
        title_label.set_valign(Gtk.Align.CENTER)
        title_label.set_wrap(True)
        title_label.set_max_width_chars(60)
        main_box.append(title_label)

        # Dodanie opisu
        description_label = Gtk.Label(label="Thanks to OpenMandriva GTK repository selector you can enable additional repository for your OpenMandriva distribution as unsupported (contrib), non-free or restricted.")
        description_label.set_margin_top(10)
        description_label.set_margin_bottom(20)
        description_label.set_halign(Gtk.Align.CENTER)
        description_label.set_valign(Gtk.Align.CENTER)
        description_label.set_wrap(True)
        description_label.set_max_width_chars(60)
        main_box.append(description_label)

        # Dodanie przycisku
        button = Gtk.Button(label="Enable Repositories")
        button.connect("clicked", self.on_button_clicked)
        main_box.append(button)

    def on_button_clicked(self, button):
        # Sprawdzanie zawartości pliku /etc/openmandriva-release
        try:
            result = subprocess.run(["cat", "/etc/openmandriva-release"], capture_output=True, text=True, check=True)
            release_info = result.stdout.strip()
            print(f"Release info: {release_info}")

            if "ROME" in release_info:
                repo_type = "rolling"
            elif "Rolling" in release_info:
                repo_type = "rolling"
            elif "ROCK" in release_info:
                repo_type = "rock"
            else:
                repo_type = "cooker"

            # Przygotowanie polecenia z odpowiednim repozytorium
            command = [
                "pkexec", "dnf", "config-manager", "--enable",
                f"{repo_type}-x86_64-extra",
                f"{repo_type}-x86_64-restricted",
                f"{repo_type}-x86_64-non-free"
            ]

            # Wywołanie polecenia
            subprocess.run(command, check=True)
            print("Repositories enabled successfully.")
        except subprocess.CalledProcessError as e:
            print(f"Error occurred: {e}")

if __name__ == '__main__':
    app = MyApp()
    app.run(None)
